@@ -85,7 +85,10 @@ class TonicAuthentication():
         Return the decoded token
         """
         if prefix != 'JWT':
-            if token.decode('utf-8') in settings_auth["TONIC_WEB_TOKEN"]:
+            if prefix == 'CWT' and token.decode('utf-8') in settings_auth["CUSTOM_WEB_TOKEN"].keys():
+                return settings_auth['CUSTOM_WEB_TOKEN'][token.decode('utf-8')]
+
+            if prefix == 'TWT' and token.decode('utf-8') in settings_auth['TONIC_WEB_TOKEN']:
                 return {
                     'name': 'Tonic Admin',
                     'is_admin': True,
