@@ -13,7 +13,7 @@ class LocaleMiddleware(object):
         self.get_response = get_response
 
     def __call__(self, request):
-        logger.info(request.headers)
+        logger.debug(request.headers)
         accept_language = request.META.get('HTTP_ACCEPT_LANGUAGE')
         if not accept_language:
             return HttpResponseBadRequest(
