@@ -1,5 +1,7 @@
 from django.http import HttpResponseBadRequest
 
+from ..global_vars import (SOFTWARE_TYPE_MOBILE, SOFTWARE_TYPE_WEB,
+                           SOFTWARE_TYPE_BACKOFFICE)
 
 class SoftwareTypeMiddleware(object):
     def __init__(self, get_response):
@@ -17,13 +19,13 @@ class SoftwareTypeMiddleware(object):
                 'Incorrect Software-Type, the available options are: Application or Web or Backoffice.'
             )
 
-        request.software_type = 'mobile'
+        request.software_type = SOFTWARE_TYPE_MOBILE
 
         if 'Web' in app_type:
-            request.software_type = 'web'
+            request.software_type = SOFTWARE_TYPE_WEB
         elif 'Backoffice' in app_type:
-            request.software_type = None
-            
+            request.software_type = SOFTWARE_TYPE_BACKOFFICE
+
         response = self.get_response(request)
 
         return response
